/*
** Module   : Block.java
** Abstract : base class for all delegated code block objects
**
** Copyright (c) 2008, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -T- --JPRM-- ----------------Description-----------------
** 001 GES 20080509 NEW   @38516 Created initial version. This is the base
**                               class for all delegated code block objects.
** 002 VMN 20130326              Added throwing ConditionException to body()
*/

package com.goldencode.p2j.util;

/**
 * Base class for all code blocks. At this time it only defines a standard
 * API and no logic.
 */
public abstract class Block
{
   /**
    * Provides a "callback" to initialize state once before the body gets
    * executed.  This is guaranteed to be called AFTER the transaction
    * manager scope opens but BEFORE the block body is ever entered. It will
    * only be called once no matter whether the block iterates or whether
    * there is a retry.
    */
   public void init()
   {
      // do nothing
   }
   
   /**
    * Provides a "callback" to execute user-defined logic at the top of the
    * block body but before the block body is executed. This is guaranteed to
    * be called AFTER the transaction manager scope opens but BEFORE the
    * block body is entered. It will be called once per iteration of the
    * block or once if the block is not iterating.  It WILL be called on
    * retry.
    */
   public void enter()
   {
      // do nothing
   }
   
   /**
    * This implements the delegated code to be executed as part of this
    * instance.
    */
   public abstract void body() throws ConditionException;
}
